@@ -6,8 +6,8 @@ use LWP::UserAgent;
 use Mouse;
 use JSON;
 use URI;
-our $VERSION = "0.03";
-use WebService::Rakuten::API::Travel;
+our $VERSION = "0.04";
+use WebService::Rakuten::API::Provider::Travel;
 use WebService::Rakuten::API::Provider::Ichiba;
 use WebService::Rakuten::API::Provider::Recipe;
 use WebService::Rakuten::API::Provider;
